@@ -14,17 +14,16 @@ Algorithm::Line::Bresenham - simple pixellated line-drawing algorithm
 
 Bresenham is one of the canonical line drawing algorithms for pixellated grids.
 Given a start and an end-point, Bresenham calculates which points on the grid
-need to be filled to generate the line between them.
+need to be filled to generate the line between them. This module has been extended
+to include cureves crcles ellipses and thick licnes, variable thickness lines.
 
-      
-        S
 
 =cut
 
 
 package Algorithm::Line::Bresenham;
 use strict; use warnings;
-our $VERSION = 0.15;
+our $VERSION = 0.151;
 use base 'Exporter';
 our @EXPORT_OK = qw/line circle ellipse_rect quad_bezier polyline varthick_line thick_line/;
 
